@@ -3,23 +3,72 @@ import os
 import tempfile
 import time
 from os.path import join as pjoin
+import shutil
 
 import lmdb
+import yaml
 
 from . import heads, parsing
-from .. import config
+from .. import constants as c
 from ..context import TxnRegister
 from .queries import RecordQuery
+from ..utils import symlink_rel
 
 
-'''
+"""
 Reading commit specifications and parents.
 ------------------------------------------
-'''
+"""
+
+
+def expand_short_commit_digest(refenv: lmdb.Environment, commit_hash: str) -> str:
+    """Find the a full commit hash from a short version provided by the user
+
+    Parameters
+    ----------
+    refenv : lmdb.Environment
+        db where the commit references are stored
+    commit_hash : str
+        short commit hash to search for in the repository
+
+    Returns
+    -------
+    str
+        full commit hash if short maps to a unique digest in the repo history
+
+    Raises
+    ------
+    KeyError
+        If the short commit hash can reference two full commit digests
+    KeyError
+        if no expanded commit digest is found starting with the short version.
+    """
+    reftxn = TxnRegister().begin_reader_txn(refenv)
+    commitParentStart = parsing.commit_parent_db_key_from_raw_key(commit_hash)
+    with reftxn.cursor() as cursor:
+        shortHashExists = cursor.set_range(commitParentStart)
+        if shortHashExists is True:
+            commitKey = cursor.key()
+            commit_key = parsing.commit_parent_raw_key_from_db_key(commitKey)
+            if commit_key.startswith(commit_hash) is False:
+                raise KeyError(f'No expanded commit hash found for short: {commit_hash}')
+            cursor.next()
+            cursor.next()
+            nextHashExist = cursor.next()
+            if nextHashExist is False:
+                return commit_key
+            nextCommitKey = cursor.key()
+            next_commit_key = parsing.commit_parent_raw_key_from_db_key(nextCommitKey)
+            if next_commit_key.startswith(commit_hash) is True:
+                raise KeyError(f'Non unique short commit hash: {commit_hash}')
+            else:
+                return commit_key
+        else:
+            raise KeyError(f'No expanded commit hash found for short: {commit_hash}')
 
 
 def check_commit_hash_in_history(refenv, commit_hash):
-    '''Check if a commit hash exists in the repository history
+    """Check if a commit hash exists in the repository history
 
     Parameters
     ----------
@@ -32,7 +81,7 @@ def check_commit_hash_in_history(refenv, commit_hash):
     -------
     bool
         True if exists, otherwise False
-    '''
+    """
     reftxn = TxnRegister().begin_reader_txn(refenv)
     try:
         commitParentKey = parsing.commit_parent_db_key_from_raw_key(commit_hash)
@@ -43,13 +92,12 @@ def check_commit_hash_in_history(refenv, commit_hash):
     return isCommitInHistory
 
 
-
 def get_commit_spec(refenv, commit_hash):
-    '''Get the commit specifications of a particular hash.
+    """Get the commit specifications of a particular hash.
 
     Parameters
     ----------
-    refenv : lmdb.Environment`
+    refenv : lmdb.Environment
         refenv where the specs are stored
     commit_hash : str
         commit hash to query
@@ -63,7 +111,7 @@ def get_commit_spec(refenv, commit_hash):
     ------
     ValueError
         if no commit exists with the provided hash
-    '''
+    """
     reftxn = TxnRegister().begin_reader_txn(refenv)
     try:
         parentCommitSpecKey = parsing.commit_spec_db_key_from_raw_key(commit_hash)
@@ -79,11 +127,11 @@ def get_commit_spec(refenv, commit_hash):
 
 
 def get_commit_ancestors(refenv, commit_hash):
-    '''find the ancestors of a particular commit hash.
+    """find the ancestors of a particular commit hash.
 
     Parameters
     ----------
-    refenv : lmdb.Environment`
+    refenv : lmdb.Environment
         lmdb environment where the commit refs are stored
     commit_hash : string
         commit hash to find the ancestors for
@@ -98,7 +146,7 @@ def get_commit_ancestors(refenv, commit_hash):
     ------
     ValueError
         if no commit exists with the provided hash
-    '''
+    """
 
     reftxn = TxnRegister().begin_reader_txn(refenv)
     try:
@@ -115,11 +163,11 @@ def get_commit_ancestors(refenv, commit_hash):
 
 
 def get_commit_ancestors_graph(refenv, starting_commit):
-    '''returns a DAG of all commits which start at some hash as they point to the repo root.
+    """returns a DAG of all commits starting at some hash pointing to the repo root.
 
     Parameters
     ----------
-    refenv : lmdb.Environment`
+    refenv : lmdb.Environment
         lmdb environment where the commit refs are stored
     starting_commit : string
         commit hash to start creating the DAG from
@@ -130,7 +178,7 @@ def get_commit_ancestors_graph(refenv, starting_commit):
         a dictionary where each key is a commit hash encountered along the way,
         and it's value is a list containing either one or two elements which
         identify the child commits of that parent hash.
-    '''
+    """
     parent_commit = starting_commit
     commit_graph = {}
     seen = set(starting_commit)
@@ -170,14 +218,14 @@ def get_commit_ancestors_graph(refenv, starting_commit):
     return commit_graph
 
 
-'''
+"""
 Methods for reading packed commit data and reconstructing an unpacked format.
 -----------------------------------------------------------------------------
-'''
+"""
 
 
 def get_commit_ref(refenv, commit_hash):
-    '''Read the commit data record references from a specific commit.
+    """Read the commit data record references from a specific commit.
 
     This only returns a list of tuples with binary encoded key/value pairs.
 
@@ -198,7 +246,7 @@ def get_commit_ref(refenv, commit_hash):
     ------
     ValueError
         if no commit exists with the provided hash
-    '''
+    """
     reftxn = TxnRegister().begin_reader_txn(refenv)
     try:
         commitRefKey = parsing.commit_ref_db_key_from_raw_key(commit_hash)
@@ -214,13 +262,13 @@ def get_commit_ref(refenv, commit_hash):
 
 
 def get_commit_ref_contents(refenv, commit_hash):
-    '''hackish way to convert lmdb from compressed structure to in memory without a new env.
+    """hackish way to convert lmdb from compressed structure to in memory without a new env.
 
     .. todo:: Completly refactor this mess...
 
     Parameters
     ----------
-    refenv : lmdb.Environment`
+    refenv : lmdb.Environment
         lmdb environment where the commit refs are stored
     commit_hash : str
         hash of the commit to get the contents of
@@ -229,12 +277,10 @@ def get_commit_ref_contents(refenv, commit_hash):
     -------
     dict
         nested dict
-    '''
-    LMDB_CONFIG = config.get('hangar.lmdb')
-
+    """
     with tempfile.TemporaryDirectory() as tempD:
         tmpDF = os.path.join(tempD, 'test.lmdb')
-        tmpDB = lmdb.open(path=tmpDF, **LMDB_CONFIG)
+        tmpDB = lmdb.open(path=tmpDF, **c.LMDB_SETTINGS)
         unpack_commit_ref(refenv, tmpDB, commit_hash)
         outDict = RecordQuery(tmpDB).all_records()
         tmpDB.close()
@@ -243,7 +289,7 @@ def get_commit_ref_contents(refenv, commit_hash):
 
 
 def unpack_commit_ref(refenv, cmtrefenv, commit_hash):
-    '''unpack a commit record ref into a new key/val db for reader checkouts.
+    """unpack a commit record ref into a new key/val db for reader checkouts.
 
     Parameters
     ----------
@@ -253,7 +299,7 @@ def unpack_commit_ref(refenv, cmtrefenv, commit_hash):
         environment handle open for writing on disk. this db must be empty.
     commit_hash : str
         hash of the commit to read in from refs and unpack in a checkout.
-    '''
+    """
 
     commitRefs = get_commit_ref(refenv=refenv, commit_hash=commit_hash)
     cmttxn = TxnRegister().begin_writer_txn(cmtrefenv)
@@ -263,15 +309,17 @@ def unpack_commit_ref(refenv, cmtrefenv, commit_hash):
             cursor.putmulti(commitRefs, append=True)
         try:
             cursor.close()
-        except Exception:
-            print('could not close cursor')
+        except Exception as e:
+            msg = 'could not close cursor cmttxn: {cmttxn} commit_hash: {commit_hash}'
+            e.args = (*e.args, msg)
+            raise e
     finally:
         TxnRegister().commit_writer_txn(cmtrefenv)
 
     return
 
 
-'''
+"""
 Methods to write new commits
 ----------------------------
 
@@ -282,13 +330,17 @@ The functions below act to:
     - Coordinate record hashing
     - Write the commit record
     - Update the branch head to point to the new commit hash
-'''
+"""
 
 # ---------------- Functions to format the writen values of a commit --------------------
 
 
-def __commit_ancestors(branchenv, *, is_merge_commit=False, master_branch_name='', dev_branch_name=''):
-    '''Format the commit parent db value, finding HEAD commits automatically.
+def _commit_ancestors(branchenv: lmdb.Environment,
+                      *,
+                      is_merge_commit: bool = False,
+                      master_branch_name: str = '',
+                      dev_branch_name: str = '') -> bytes:
+    """Format the commit parent db value, finding HEAD commits automatically.
 
     This method handles formating for both regular & merge commits through the
     the keyword only arguments.
@@ -309,10 +361,10 @@ def __commit_ancestors(branchenv, *, is_merge_commit=False, master_branch_name='
 
     Returns
     -------
-    bytestring
-        Commit parent db value formated appropriatly based on the repo state and
+    bytes
+        Commit parent db value formatted appropriately based on the repo state and
         any specified arguments.
-    '''
+    """
     if not is_merge_commit:
         masterBranch = heads.get_staging_branch_head(branchenv)
         master_ancestor = heads.get_branch_head_commit(branchenv, masterBranch)
@@ -329,8 +381,8 @@ def __commit_ancestors(branchenv, *, is_merge_commit=False, master_branch_name='
     return commitParentVal
 
 
-def __commit_spec(message, user, email):
-    '''Format the commit specification according to the supplied username and email.
+def _commit_spec(message: str, user: str, email: str) -> bytes:
+    """Format the commit specification according to the supplied username and email.
 
     This method currently only acts as a pass through to the parsing options
     (with time filled in).
@@ -346,24 +398,23 @@ def __commit_spec(message, user, email):
 
     Returns
     -------
-    bytestring
-        Formated value for the specification field of the commit.
-    '''
+    bytes
+        Formatted value for the specification field of the commit.
+    """
     commitSpecVal = parsing.commit_spec_db_val_from_raw_val(
         commit_time=time.time(),
         commit_message=message,
         commit_user=user,
         commit_email=email)
-
     return commitSpecVal
 
 
-def __commit_ref(stageenv):
-    '''Query and format all staged data records, and format it for ref storage.
+def _commit_ref(stageenv: lmdb.Environment) -> bytes:
+    """Query and format all staged data records, and format it for ref storage.
 
     Parameters
     ----------
-    stageenv : lmdb.Environment`
+    stageenv : lmdb.Environment
         lmdb environment where the staged record data is actually stored.
 
     Returns
@@ -371,9 +422,9 @@ def __commit_ref(stageenv):
     bytes
         Serialized and compressed version of all staged record data.
 
-    '''
+    """
     querys = RecordQuery(dataenv=stageenv)
-    allRecords = querys._traverse_all_records()
+    allRecords = tuple(querys._traverse_all_records())
     commitRefVal = parsing.commit_ref_db_val_from_raw_val(allRecords)
     return commitRefVal
 
@@ -383,7 +434,7 @@ def __commit_ref(stageenv):
 
 def commit_records(message, branchenv, stageenv, refenv, repo_path,
                    *, is_merge_commit=False, merge_master=None, merge_dev=None):
-    '''Commit all staged records to the repository, updating branch HEAD as needed.
+    """Commit all staged records to the repository, updating branch HEAD as needed.
 
     This method is intended to work for both merge commits as well as regular
     ancestor commits.
@@ -393,12 +444,12 @@ def commit_records(message, branchenv, stageenv, refenv, repo_path,
     message : string
         Message the user accociates with what has been added, removed, or
         changed in this commit. Must not be empty.
-    branchenv : lmdb.Environment`
+    branchenv : lmdb.Environment
         lmdb environment where branch records are stored.
-    stageenv : lmdb.Environment`
+    stageenv : lmdb.Environment
         lmdb environment where the staged data records are stored in
         uncompressed format.
-    refenv : lmdb.Environment`
+    refenv : lmdb.Environment
         lmdb environment where the commit ref records are stored.
     is_merge_commit : bool, optional
         Is the commit a merge commit or not? defaults to False
@@ -411,20 +462,23 @@ def commit_records(message, branchenv, stageenv, refenv, repo_path,
     -------
     string
         Commit hash of the newly added commit
-    '''
-    commitParentVal = __commit_ancestors(
-        branchenv=branchenv,
-        is_merge_commit=is_merge_commit,
-        master_branch_name=merge_master,
-        dev_branch_name=merge_dev)
+    """
+    commitParentVal = _commit_ancestors(branchenv=branchenv,
+                                         is_merge_commit=is_merge_commit,
+                                         master_branch_name=merge_master,
+                                         dev_branch_name=merge_dev)
 
-    USER_NAME = config.get('user.name')
-    USER_EMAIL = config.get('user.email')
+    user_info_pth = pjoin(repo_path, 'config_user.yml')
+    with open(user_info_pth) as f:
+        user_info = yaml.safe_load(f.read()) or {}
+
+    USER_NAME = user_info['name']
+    USER_EMAIL = user_info['email']
     if (USER_NAME is None) or (USER_EMAIL is None):
         raise RuntimeError(f'Username and Email are required. Please configure.')
 
-    commitSpecVal = __commit_spec(message=message, user=USER_NAME, email=USER_EMAIL)
-    commitRefVal = __commit_ref(stageenv=stageenv)
+    commitSpecVal = _commit_spec(message=message, user=USER_NAME, email=USER_EMAIL)
+    commitRefVal = _commit_ref(stageenv=stageenv)
 
     hasher = hashlib.blake2b(digest_size=20)
     hasher.update(commitParentVal)
@@ -460,7 +514,7 @@ def commit_records(message, branchenv, stageenv, refenv, repo_path,
 
 
 def replace_staging_area_with_commit(refenv, stageenv, commit_hash):
-    '''DANGER ZONE: Delete the stage db and replace it with a copy of a commit environent.
+    """DANGER ZONE: Delete the stage db and replace it with a copy of a commit environent.
 
     .. warning::
 
@@ -475,7 +529,7 @@ def replace_staging_area_with_commit(refenv, stageenv, commit_hash):
         lmdb environment opened to the staging area.
     commit_hash : str
         commit hash to read from the refenv and replace the stage contents with.
-    '''
+    """
     stagetxn = TxnRegister().begin_writer_txn(stageenv)
     with stagetxn.cursor() as cursor:
         positionExists = cursor.first()
@@ -489,7 +543,7 @@ def replace_staging_area_with_commit(refenv, stageenv, commit_hash):
 
 
 def replace_staging_area_with_refs(stageenv, sorted_content):
-    '''DANGER ZONE: Delete all stage db records and replace it with specified data.
+    """DANGER ZONE: Delete all stage db records and replace it with specified data.
 
     .. warning::
 
@@ -505,7 +559,7 @@ def replace_staging_area_with_refs(stageenv, sorted_content):
         stageenv db. index 0 -> db key; index 1 -> db val, it is assumed that the
         order of the tuples is lexigraphically sorted by index 0 values, if not,
         this will result in unknown behavior.
-    '''
+    """
     stagetxn = TxnRegister().begin_writer_txn(stageenv)
     with stagetxn.cursor() as cursor:
         positionExists = cursor.first()
@@ -525,14 +579,14 @@ def replace_staging_area_with_refs(stageenv, sorted_content):
 
 
 def move_process_data_to_store(repo_path: str, *, remote_operation: bool = False):
-    '''Move symlinks to hdf5 files from process directory to store directory
+    """Move symlinks to hdf5 files from process directory to store directory
 
     In process writes never directly access files in the data directory.
     Instead, when the file is created is is symlinked to either the remote data
     or stage data directory. All access is handled through this intermediate
-    symlink in order to prevent any ability to overwrite commit data (even if
+    symlink in order to prevent any ability to overwpackedeven if
     there are major errors in the hash records). Once the write operation
-    complets (commit for staging, or completion of fetch for remote), this
+    packedor staging, or completion of fetch for remote), this
     method is called to move the symlinks from the write enabled directory to
     the (read only, fully-committed) storage dir.
 
@@ -545,39 +599,37 @@ def move_process_data_to_store(repo_path: str, *, remote_operation: bool = False
         default is False, which means that all changes will occur in the staging
         area)
 
-    '''
-    STORE_DATA_DIR = config.get('hangar.repository.store_data_dir')
-    store_dir = pjoin(repo_path, STORE_DATA_DIR)
+    """
+    store_dir = pjoin(repo_path, c.DIR_DATA_STORE)
 
-    if remote_operation:
-        REMOTE_DATA_DIR = config.get('hangar.repository.remote_data_dir')
-        process_dir = pjoin(repo_path, REMOTE_DATA_DIR)
+    if not remote_operation:
+        process_dir = pjoin(repo_path, c.DIR_DATA_STAGE)
     else:
-        STAGE_DATA_DIR = config.get('hangar.repository.stage_data_dir')
-        process_dir = pjoin(repo_path, STAGE_DATA_DIR)
+        process_dir = pjoin(repo_path, c.DIR_DATA_REMOTE)
 
-    p_schema_dirs = [x for x in os.listdir(process_dir) if x.startswith('hdf_')]
-    for p_schema_dir in p_schema_dirs:
-        schema_dir_pth = pjoin(process_dir, p_schema_dir)
-        p_files = [x for x in os.listdir(schema_dir_pth) if x.endswith('.hdf5')]
-        store_schema_dir_pth = pjoin(store_dir, p_schema_dir)
+    dirs_to_make, symlinks_to_make = [], []
+    for root, dirs, files in os.walk(process_dir):
+        for d in dirs:
+            dirs_to_make.append(os.path.relpath(pjoin(root, d), process_dir))
+        for f in files:
+            store_file_pth = pjoin(store_dir, os.path.relpath(pjoin(root, f), process_dir))
+            link_file_pth = os.path.normpath(pjoin(root, os.readlink(pjoin(root, f))))
+            symlinks_to_make.append((link_file_pth, store_file_pth))
 
-        for p_file in p_files:
-            if not os.path.isdir(store_schema_dir_pth):
-                os.makedirs(store_schema_dir_pth)
-            p_fp = pjoin(schema_dir_pth, p_file)
-            p_relpth = os.readlink(p_fp)
-            store_fp = pjoin(store_schema_dir_pth, p_file)
-            os.symlink(p_relpth, store_fp)
-            os.remove(p_fp)
+    for d in dirs_to_make:
+        dpth = pjoin(store_dir, d)
+        if not os.path.isdir(dpth):
+            os.makedirs(dpth)
+    for src, dest in symlinks_to_make:
+        symlink_rel(src, dest)
 
-        os.removedirs(schema_dir_pth)
-
-    os.makedirs(process_dir, exist_ok=True)
+    # reset before releasing control.
+    shutil.rmtree(process_dir)
+    os.makedirs(process_dir)
 
 
 def list_all_commits(refenv):
-    '''returns a list of all commits stored in the repostiory
+    """returns a list of all commits stored in the repostiory
 
     Parameters
     ----------
@@ -588,7 +640,7 @@ def list_all_commits(refenv):
     -------
     list
         list of all commit digests.
-    '''
+    """
     refTxn = TxnRegister().begin_reader_txn(refenv)
     try:
         commits = set()
